==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralRealSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralReal;
import io.ciera.tool.sql.ooaofooa.value.LiteralRealSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralRealSetImpl extends InstanceSet<LiteralRealSet,LiteralReal> implements LiteralRealSet {

    // attributes
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralReal literalreal : this ) literalreal.setValue( m_Value );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralReal literalreal : this ) literalreal.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralReal literalreal : this ) valueset.add( literalreal.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralReal nullElement() {
        return LiteralRealImpl.EMPTY_LITERALREAL;
    }

    @Override
    public LiteralRealSet emptySet() {
      return new LiteralRealSetImpl();
    }

    @Override
    public LiteralRealSet value() {
        return this;
    }

    @Override
    public List<LiteralReal> elements() {
        return Arrays.asList(toArray(new LiteralReal[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralRealSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralReal;
import io.ciera.tool.sql.ooaofooa.value.LiteralRealSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralRealSetImpl extends InstanceSet<LiteralRealSet,LiteralReal> implements LiteralRealSet {

    public LiteralRealSetImpl() {
    }

    public LiteralRealSetImpl(Comparator<? super LiteralReal> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralReal literalreal : this ) literalreal.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralReal literalreal : this ) literalreal.setValue( m_Value );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralReal literalreal : this ) valueset.add( literalreal.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralReal nullElement() {
        return LiteralRealImpl.EMPTY_LITERALREAL;
    }

    @Override
    public LiteralRealSet emptySet() {
      return new LiteralRealSetImpl();
    }

    @Override
    public LiteralRealSet emptySet(Comparator<? super LiteralReal> comp) {
      return new LiteralRealSetImpl(comp);
    }

    @Override
    public LiteralRealSet value() {
        return this;
    }

    @Override
    public List<LiteralReal> elements() {
        return Arrays.asList(toArray(new LiteralReal[0]));
    }

}
